@@ -13,12 +13,12 @@ matplotlib.use('TkAgg')
 target_column = 'target'
 
 ################################################################################################
-# df1 = load_data_pirates().assign(target='pirate').sample(300, replace=True)
-# df2 = load_data_king_arthur().assign(target='arthur').sample(300, replace=True)
-# df3 = load_data_chat_logs().assign(target='chat').sample(300, replace=True)
-# df = pd.concat([df1, df2
-#                 , df3
-#                 ])
+df1 = load_data_pirates().assign(target='pirate')  # .sample(300, replace=True)
+df2 = load_data_king_arthur().assign(target='arthur')  # .sample(300, replace=True)
+df3 = load_data_chat_logs().assign(target='chat')  # .sample(300, replace=True)
+df = pd.concat([df1, df2
+                   , df3
+                ])
 
 
 # df['target'] = df['target'].apply(lambda x: 0 if "pirate" in x else 1)  # can do with or without
@@ -77,8 +77,8 @@ target_column = 'target'
 
 
 ################################################################################################
-df = pd.read_csv("chester/run_manual_chester/HR_Analytics.csv.csv")
-df.rename(columns={'Attrition': 'target'}, inplace=True)
+# df = pd.read_csv("chester/run_manual_chester/HR_Analytics.csv.csv")
+# df.rename(columns={'Attrition': 'target'}, inplace=True)
 ###############################################################################################
 
 
